@@ -7,10 +7,10 @@
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -26,8 +26,11 @@
 
 #include <gphoto2/gphoto2-port-log.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "crctab.h"
 
+
 #define GP_MODULE "ricoh"
 
 #define STX 0x02 /* start of text */
@@ -37,24 +40,6 @@
 #define ETB 0x17 /* end of transmission block */
 #define DLE 0x10 /* datalink escape */
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif 
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define CR(result)       {int r_mac=(result); if (r_mac<0) return r_mac;}
 #define CRF(result,data) {int r_mac=(result); \
@@ -98,7 +83,9 @@ ricoh_send (Camera *camera, GPContext *context, unsigned char cmd,
 	/* First, make sure there is no data coming from the camera. */
 	CR (gp_port_get_timeout (camera->port, &timeout));
 	CR (gp_port_set_timeout (camera->port, 20));
-	while (gp_port_read (camera->port, (char *)buf, 1) >= 0);
+	while (gp_port_read (camera->port, (char *)buf, 1) >= 0) {
+	  /* do nothing */
+	}
 	CR (gp_port_set_timeout (camera->port, timeout));
 
 	/* Write header */
@@ -285,7 +272,7 @@ ricoh_transmit (Camera *camera, GPContext *context, unsigned char cmd,
         unsigned char ret_cmd;
 	unsigned int r = 0;
 	int result;
- 
+
         while (1) {
                 CR (ricoh_send (camera, context, cmd, 0, data, len));
                 result = ricoh_recv (camera, context, &ret_cmd, NULL,
@@ -415,7 +402,7 @@ ricoh_get_pic_date (Camera *camera, GPContext *context, unsigned int n,
 	if (date) {
 		time.tm_year = B2H (buf[1]);
 		/* correct for Y2K in case older images are read */
-		if (time.tm_year < 90) time.tm_year += 100;			
+		if (time.tm_year < 90) time.tm_year += 100;
 		time.tm_mon  = B2H (buf[2]) - 1;
 		time.tm_mday = B2H (buf[3]);
 		time.tm_hour = B2H (buf[4]);
@@ -586,9 +573,9 @@ ricoh_get_pic (Camera *camera, GPContext *context, unsigned int n,
 	unsigned int r, header_len;
 	RicohMode mode;
 
-	GP_DEBUG ("Getting image %i as %s...", n, 
+	GP_DEBUG ("Getting image %i as %s...", n,
 							(type==RICOH_FILE_TYPE_PREVIEW ? "thumbnail":"image"));
-	
+
 	/* Put camera into play mode, if not already */
 	CR (ricoh_get_mode (camera, context, &mode));
 	if (mode != RICOH_MODE_PLAY)
@@ -673,9 +660,9 @@ ricoh_set_date (Camera *camera, GPContext *context, time_t time)
 	t = localtime (&time);
 #ifdef HAVE_TM_GMTOFF
 	time += t->tm_gmtoff;
-#else  
+#else
 	time += timezone;
-#endif 
+#endif
 	t = localtime (&time);
 	GP_DEBUG ("ricoh_set_date: converted time to localtime %s "
 		  "(timezone is %ld)", asctime (t), timezone);
@@ -843,7 +830,7 @@ ricoh_put_file (Camera *camera, GPContext *context, const char *name,
 	C_LEN (context, len, 2);
 
 	/*
-	 * We just received the picture number of the new file. We don't 
+	 * We just received the picture number of the new file. We don't
 	 * need it.
 	 */
 
@@ -852,7 +839,7 @@ ricoh_put_file (Camera *camera, GPContext *context, const char *name,
 	for (i = 0; i < size; i += 128) {
 		memset (block, 0, sizeof (buf));
 		memcpy (block, data + i, MIN (128, size - i));
-		CR (ricoh_transmit (camera, context, 0xa2, block, 128, 
+		CR (ricoh_transmit (camera, context, 0xa2, block, 128,
 				    buf, &len));
 		C_LEN (context, len, 0);
 		if (gp_context_cancel (context) == GP_CONTEXT_FEEDBACK_CANCEL)
