@@ -27,6 +27,9 @@
 
 #include <gphoto2/gphoto2-library.h>
 
+#include "libgphoto2/i18n.h"
+
+
 /* The commands */
 #define SDSC_START      0x43
 #define SDSC_NEXT     0x53
@@ -44,19 +47,6 @@
 
 #define CHECK_RESULT(result) {int r = result; if (r < 0) return (r);}
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 static int
 SDSC_send (GPPort *port, unsigned char command)
