@@ -1,3 +1,5 @@
+#include <stdio.h>
+
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-camera.h>
 #include <gphoto2/gphoto2-list.h>
@@ -15,12 +17,17 @@
 #include <gphoto2/gphoto2-port-result.h>
 #include <gphoto2/gphoto2-port-version.h>
 
-#include <stdio.h>
-
+#ifdef __STDC_VERSION__
+static
 unsigned long stdc_version = __STDC_VERSION__;
+#endif
 
 int main()
 {
+#ifdef __STDC_VERSION__
   printf("stdc_version = %lu\n", stdc_version);
+#else
+  printf("stdc_version = undefined\n");
+#endif
   return 0;
 }
